@@ -3,6 +3,7 @@
 import logging
 import os
 import sys
+from pathlib import Path
 
 import click
 import click_log
@@ -28,7 +29,7 @@ from .hvcs import (
     post_changelog,
     upload_to_release,
 )
-from .pypi import upload_to_pypi
+from .repository import ArtifactRepo
 from .settings import config, overload_configuration
 from .vcs_helpers import (
     checkout,
@@ -42,11 +43,14 @@ from .vcs_helpers import (
 
 logger = logging.getLogger("semantic_release")
 
-SECRET_NAMES = [
-    "PYPI_USERNAME",
-    "PYPI_PASSWORD",
-    "GH_TOKEN",
-    "GL_TOKEN",
+TOKEN_VARS = [
+    "github_token_var",
+    "gitlab_token_var",
+    "pypi_pass_var",
+    "pypi_token_var",
+    "pypi_user_var",
+    "repository_user_var",
+    "repository_pass_var",
 ]
 
 COMMON_OPTIONS = [
@@ -228,11 +232,11 @@ def changelog(*, unreleased=False, noop=False, post=False, **kwargs):
             logger.error("Missing token: cannot post changelog to HVCS")
 
 
-def publish(**kwargs):
-    """Run the version task, then push to git and upload to PyPI / GitHub Releases."""
+def publish(retry: bool = False, noop: bool = False, **kwargs):
+    """Run the version task, then push to git and upload to an artifact repository / GitHub Releases."""
     current_version = get_current_version()
 
-    retry = kwargs.get("retry")
+    verbose = logger.isEnabledFor(logging.DEBUG)
     if retry:
         logger.info("Retry is on")
         # The "new" version will actually be the current version, and the
@@ -256,7 +260,7 @@ def publish(**kwargs):
         current_version=current_version,
         new_version=new_version,
         retry=retry,
-        noop=kwargs.get("noop"),
+        noop=noop,
     ):
         log = generate_changelog(current_version)
         changelog_md = markdown_changelog(
@@ -283,13 +287,8 @@ def publish(**kwargs):
 
         # Get config options for uploads
         dist_path = config.get("dist_path")
-        upload_pypi = config.get("upload_to_pypi")
-        upload_to_pypi_glob_patterns = config.get("upload_to_pypi_glob_patterns")
         upload_release = config.get("upload_to_release")
 
-        if upload_to_pypi_glob_patterns:
-            upload_to_pypi_glob_patterns = upload_to_pypi_glob_patterns.split(",")
-
         if should_build():
             # We need to run the command to build wheels for releasing
             logger.info("Building distributions")
@@ -298,13 +297,10 @@ def publish(**kwargs):
                 remove_dists(dist_path)
             build_dists()
 
-        if upload_pypi:
-            logger.info("Uploading to PyPI")
-            upload_to_pypi(
-                path=dist_path,
-                # If we are retrying, we don't want errors for files that are already on PyPI.
-                skip_existing=retry,
-                glob_patterns=upload_to_pypi_glob_patterns,
+        if ArtifactRepo.upload_enabled():
+            logger.info("Uploading to artifact Repository")
+            ArtifactRepo(Path(dist_path)).upload(
+                noop=noop, verbose=verbose, skip_existing=retry
             )
 
         if check_token():
@@ -339,7 +335,8 @@ def publish(**kwargs):
 def filter_output_for_secrets(message):
     """Remove secrets from cli output."""
     output = message
-    for secret_name in SECRET_NAMES:
+    for token_var in TOKEN_VARS:
+        secret_name = config.get(token_var)
         secret = os.environ.get(secret_name)
         if secret != "" and secret is not None:
             output = output.replace(secret, f"${secret_name}")
@@ -370,7 +367,8 @@ def entry():
 def main(**kwargs):
     logger.debug(f"Main args: {kwargs}")
     message = ""
-    for secret_name in SECRET_NAMES:
+    for token_var in TOKEN_VARS:
+        secret_name = config.get(token_var)
         message += f'{secret_name}="{os.environ.get(secret_name)}",'
     logger.debug(f"Environment: {filter_output_for_secrets(message)}")
 
@@ -383,6 +381,7 @@ def main(**kwargs):
         "patch_without_tag",
         "major_on_zero",
         "upload_to_pypi",
+        "upload_to_repository",
         "version_source",
         "no_git_tag",
     ]:
